clean: Clean the pheontype and expression data from TCGA

Description Usage Arguments Details Value Examples

View source: R/clean.R

Description

Delete the duplicated individual and rename the colnames.

Usage

1
clean(phe, expr)

Arguments

phe

data.frame, the raw expression matrix with colname of molecular id and individual ids.

expr

data.frame, the raw expression matrix with colname of molecular id and individual ids.

Details

nothing

Value

data.frame, the clean expression matrix with colname of molecular id and individual ids.

Examples

1
2
data(phe);data(expr)
cleanData = clean(phe,expr)

Feng-Zhang/signatureFlow documentation built on Dec. 17, 2021, 8:26 p.m.