Description Usage Arguments Details Value Examples
Delete the duplicated individual and rename the colnames.
1 | cleanExpr(expr)
|
expr |
data.frame, the raw expression matrix with colname of molecular id and individual ids. |
nothing
data.frame, the clean expression matrix with colname of molecular id and individual ids.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.