cleanphe: Clean the phenotype data from TCGA

Description Usage Arguments Details Value Examples

View source: R/clean.R

Description

Given a phenotype data frame, delete the individual with NA .

Usage

1
cleanphe(phe)

Arguments

phe

data.frame, the raw expression matrix with colname of molecular id and individual ids.

Details

nothing

Value

data.frame, the clean expression matrix with colname of molecular id and individual ids.

Examples

1
data(phe);phe = cleanphe(phe)

Feng-Zhang/signatureFlow documentation built on Dec. 17, 2021, 8:26 p.m.