Description Usage Arguments Details Value Examples
Given a phenotype data frame, delete the individual with NA .
1 | cleanphe(phe)
|
phe |
data.frame, the raw expression matrix with colname of molecular id and individual ids. |
nothing
data.frame, the clean expression matrix with colname of molecular id and individual ids.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.